======
IO
======


.. currentmodule:: aydin.io.io

.. autofunction:: is_batch
.. autofunction:: is_channel

.. autoclass:: FileMetadata
   :members:
   :inherited-members:

.. autofunction:: imread
.. autofunction:: imwrite
